==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/HttpGetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.HttpGetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Model representing a http get request.
 * @property fileName Name of the file that the request should be saved to.
 * @property headers List of headers to send with the request.
 * @property url URL to make HTTP GET request against.
 */
public data class HttpGetArgs(
    public val fileName: Output<String>? = null,
    public val headers: Output<List<String>>? = null,
    public val url: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.HttpGetArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.HttpGetArgs =
        com.pulumi.azurenative.app.inputs.HttpGetArgs.builder()
            .fileName(fileName?.applyValue({ args0 -> args0 }))
            .headers(headers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .url(url.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HttpGetArgs].
 */
@PulumiTagMarker
public class HttpGetArgsBuilder internal constructor() {
    private var fileName: Output<String>? = null

    private var headers: Output<List<String>>? = null

    private var url: Output<String>? = null

    /**
     * @param value Name of the file that the request should be saved to.
     */
    @JvmName("xdppedoadrpvrwna")
    public suspend fun fileName(`value`: Output<String>) {
        this.fileName = value
    }

    /**
     * @param value List of headers to send with the request.
     */
    @JvmName("bkeqjdoyidvovvfq")
    public suspend fun headers(`value`: Output<List<String>>) {
        this.headers = value
    }

    @JvmName("ugynegcfvrgwfdwh")
    public suspend fun headers(vararg values: Output<String>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values List of headers to send with the request.
     */
    @JvmName("axmiudwusgqlinlg")
    public suspend fun headers(values: List<Output<String>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value URL to make HTTP GET request against.
     */
    @JvmName("varfdgxgmhscikaf")
    public suspend fun url(`value`: Output<String>) {
        this.url = value
    }

    /**
     * @param value Name of the file that the request should be saved to.
     */
    @JvmName("oorrasliyvvdbbuc")
    public suspend fun fileName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileName = mapped
    }

    /**
     * @param value List of headers to send with the request.
     */
    @JvmName("crwsdanybmfpwwqw")
    public suspend fun headers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param values List of headers to send with the request.
     */
    @JvmName("apjemspcdaqquwxi")
    public suspend fun headers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value URL to make HTTP GET request against.
     */
    @JvmName("esxisslubusrusiw")
    public suspend fun url(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.url = mapped
    }

    internal fun build(): HttpGetArgs = HttpGetArgs(
        fileName = fileName,
        headers = headers,
        url = url ?: throw PulumiNullFieldException("url"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/app/kotlin/inputs/HttpGetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.app.kotlin.inputs

import com.pulumi.azurenative.app.inputs.HttpGetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Model representing a http get request.
 * @property fileName Name of the file that the request should be saved to.
 * @property headers List of headers to send with the request.
 * @property url URL to make HTTP GET request against.
 */
public data class HttpGetArgs(
    public val fileName: Output<String>? = null,
    public val headers: Output<List<String>>? = null,
    public val url: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.app.inputs.HttpGetArgs> {
    override fun toJava(): com.pulumi.azurenative.app.inputs.HttpGetArgs =
        com.pulumi.azurenative.app.inputs.HttpGetArgs.builder()
            .fileName(fileName?.applyValue({ args0 -> args0 }))
            .headers(headers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .url(url.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HttpGetArgs].
 */
@PulumiTagMarker
public class HttpGetArgsBuilder internal constructor() {
    private var fileName: Output<String>? = null

    private var headers: Output<List<String>>? = null

    private var url: Output<String>? = null

    /**
     * @param value Name of the file that the request should be saved to.
     */
    @JvmName("yfgiludtgvatlbeo")
    public suspend fun fileName(`value`: Output<String>) {
        this.fileName = value
    }

    /**
     * @param value List of headers to send with the request.
     */
    @JvmName("cthgbxshktqqxbll")
    public suspend fun headers(`value`: Output<List<String>>) {
        this.headers = value
    }

    @JvmName("jbatxsasleysxxlt")
    public suspend fun headers(vararg values: Output<String>) {
        this.headers = Output.all(values.asList())
    }

    /**
     * @param values List of headers to send with the request.
     */
    @JvmName("skfxuqwcbihwrsof")
    public suspend fun headers(values: List<Output<String>>) {
        this.headers = Output.all(values)
    }

    /**
     * @param value URL to make HTTP GET request against.
     */
    @JvmName("wrqcrcvdsdijiehp")
    public suspend fun url(`value`: Output<String>) {
        this.url = value
    }

    /**
     * @param value Name of the file that the request should be saved to.
     */
    @JvmName("ctmsbvyxljyyugcc")
    public suspend fun fileName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileName = mapped
    }

    /**
     * @param value List of headers to send with the request.
     */
    @JvmName("jfaeyagpluwvtucm")
    public suspend fun headers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param values List of headers to send with the request.
     */
    @JvmName("emechecwpngvfank")
    public suspend fun headers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.headers = mapped
    }

    /**
     * @param value URL to make HTTP GET request against.
     */
    @JvmName("ruyyydmnbdhyqtpq")
    public suspend fun url(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.url = mapped
    }

    internal fun build(): HttpGetArgs = HttpGetArgs(
        fileName = fileName,
        headers = headers,
        url = url ?: throw PulumiNullFieldException("url"),
    )
}
